#
# spec file for package k8senv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           k8senv
Version:        1.1.1
Release:        1.3
Summary:        Manage multiple versions of kubectl, helm and velero clients on same system/jumpbox/bastion
License:        MIT
URL:            https://github.com/navilg/k8senv
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
Kubernetes client's version manager inspired by tfenv

Kubernetes clients supported at this moments are kubectl, or, helm, or, velero
on Linux servers/machines.

Manytimes we need to manage many Kubernetes clusters from same jumpbox or
machine or bastion server. Those many cluster may have different versions of
Kubernetes. In that case, It becomes difficult to use multiple versions of
Kubernetes clients to communicate with those different versions of clusters.

This small tool is to help manage different versions of Kubernetes clients.
Kubernetes clients kubectl, helm and velero are supported at this stage.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

# https://github.com/navilg/k8senv/blob/main/build.sh#L7
sed -i "/^var gitCommit/ s/###GitCommitPlaceholder###/${COMMIT_HASH}/" ./internal/config/config.go

go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/%{name} main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Sun Nov  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.1:
  * remove armv7 from docker release
  * update dockerfile
  * release v1.1.1
  * makes sure patch version does not contain any build or subpatch
    version
  * fix #32
* Tue Oct 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.1.0:
  * Change k8senv version to 1.1.0
  * add support for "auto" as velero version
  * add support for "auto" as kubectl version with use subcommand
  * add support for "auto" as kubectl version with install
    subcommand
* Sun Oct 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.0.3:
  * bump go 1.23
  * doc: Improve documentation
  * doc: Update latest version
  * doc: Add demo video
* Mon Sep 23 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package k8senv: manage multiple versions of kubectl, helm and
  velero clients on same system/jumpbox/bastion
